summaryrefslogtreecommitdiffstats
path: root/examples2/menu.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples2/menu.py')
-rwxr-xr-xexamples2/menu.py92
1 files changed, 46 insertions, 46 deletions
diff --git a/examples2/menu.py b/examples2/menu.py
index 89938c3..a8efe7b 100755
--- a/examples2/menu.py
+++ b/examples2/menu.py
@@ -5,7 +5,7 @@
#**
#** Copyright (C) 1992-1998 Troll Tech AS. All rights reserved.
#**
#** This file is part of an example program for PyQt. This example
#** program may be used, distributed and modified without limitation.
#**
#*****************************************************************************/
@@ -114,35 +114,35 @@ p4_xpm = [
# Auxiliary class to provide fancy menu items with different fonts.
# Used for the "bold" and "underline" menu items in the options menu.
-#class MyMenuItem( QCustomMenuItem ):
+#class MyMenuItem( TQCustomMenuItem ):
# def __init__( self, s=None, f=None ):
-# apply( QCustomMenuItem.__init__,( self, s, f ) )
-# string = QString( s )
-# font = QFont( f )
+# apply( TQCustomMenuItem.__init__,( self, s, f ) )
+# string = TQString( s )
+# font = TQFont( f )
# def paint( self, p, TRUE, FALSE, x, y, w, h ) :
# p.setFont ( font )
-# p.drawText( x, y, w, h, Qt.AlignLeft | Qt.AlignVCenter | Qt.ShowPrefix | Qt.DontClip, string )
+# p.drawText( x, y, w, h, TQt.AlignLeft | TQt.AlignVCenter | TQt.ShowPrefix | TQt.DontClip, string )
# def sizeHint( self ):
# return QFontMetrics( font ).size( Qt.AlignLeft | Qt.AlignVCenter | Qt.ShowPrefix | Qt.DontClip, string )
#
### Implementation of MenuExample class
#
-class MenuExample( QWidget ):
+class MenuExample( TQWidget ):
def __init__( self, parent=None, name=None ):
- apply( QWidget.__init__,(self, parent, name) )
- self.p1 = QIconSet( QPixmap ( p1_xpm ) )
- self.p2 = QIconSet( QPixmap ( p2_xpm ) )
- self.p3 = QIconSet( QPixmap ( p3_xpm ) )
- self.p4 = QIconSet( QPixmap ( p4_xpm ) )
- #openIcon = QPixmap()
- #saveIcon = QPixmap()
- #printIcon = QPixmap()
-
- self.printer = QPopupMenu( self )
+ apply( TQWidget.__init__,(self, parent, name) )
+ self.p1 = TQIconSet( TQPixmap ( p1_xpm ) )
+ self.p2 = TQIconSet( TQPixmap ( p2_xpm ) )
+ self.p3 = TQIconSet( TQPixmap ( p3_xpm ) )
+ self.p4 = TQIconSet( TQPixmap ( p4_xpm ) )
+ #openIcon = TQPixmap()
+ #saveIcon = TQPixmap()
+ #printIcon = TQPixmap()
+
+ self.printer = TQPopupMenu( self )
#CHECK_PTR( self.printer )
self.printer.insertTearOffHandle()
self.printer.insertItem( "&Print to printer", self.printDoc )
@@ -151,25 +151,25 @@ class MenuExample( QWidget ):
self.printer.insertSeparator()
self.printer.insertItem( "Printer &Setup", self.printerSetup )
- self.file = QPopupMenu( self )
+ self.file = TQPopupMenu( self )
#CHECK_PTR( self.file );
- self.file.insertItem( self.p1, "&Open", self.open, Qt.CTRL+Qt.Key_O )
- self.file.insertItem( self.p2, "&New", self.news, Qt.CTRL+Qt.Key_N )
- self.file.insertItem( self.p3, "&Save", self.save, Qt.CTRL+Qt.Key_S )
- self.file.insertItem( "&Close", self.closeDoc, Qt.CTRL+Qt.Key_W )
+ self.file.insertItem( self.p1, "&Open", self.open, TQt.CTRL+TQt.Key_O )
+ self.file.insertItem( self.p2, "&New", self.news, TQt.CTRL+TQt.Key_N )
+ self.file.insertItem( self.p3, "&Save", self.save, TQt.CTRL+TQt.Key_S )
+ self.file.insertItem( "&Close", self.closeDoc, TQt.CTRL+TQt.Key_W )
self.file.insertSeparator()
- self.file.insertItem( self.p4, "&Print", self.printer, Qt.CTRL+Qt.Key_P )
+ self.file.insertItem( self.p4, "&Print", self.printer, TQt.CTRL+TQt.Key_P )
self.file.insertSeparator()
- self.file.insertItem( "E&xit", qApp, SLOT( "quit()" ), Qt.CTRL+Qt.Key_Q )
+ self.file.insertItem( "E&xit", qApp, SLOT( "quit()" ), TQt.CTRL+TQt.Key_Q )
- self.edit = QPopupMenu( self )
+ self.edit = TQPopupMenu( self )
#CHECK_PTR( self.edit )
undoID = self.edit.insertItem( "&Undo", self.undo )
redoID = self.edit.insertItem( "&Redo", self.redo )
self.edit.setItemEnabled( undoID, TRUE )
self.edit.setItemEnabled( redoID, FALSE )
- self.options = QPopupMenu( self )
+ self.options = TQPopupMenu( self )
#CHECK_PTR( self.options )
self.options.insertTearOffHandle()
self.options.setCaption( 'Options' )
@@ -177,23 +177,23 @@ class MenuExample( QWidget ):
self.options.insertSeparator()
self.options.polish() # adjust system settings
- self.f = QFont( self.options.font() )
+ self.f = TQFont( self.options.font() )
self.f.setBold( TRUE )
self.boldID = self.options.insertItem( "&Bold" )
- self.options.setAccel( Qt.CTRL+Qt.Key_B, self.boldID )
+ self.options.setAccel( TQt.CTRL+TQt.Key_B, self.boldID )
self.options.connectItem( self.boldID, self.bold )
- self.f = QFont( self.options.font() )
+ self.f = TQFont( self.options.font() )
self.f.setUnderline( TRUE )
self.underlineID = self.options.insertItem( "&Underline" )
- self.options.setAccel( Qt.CTRL+Qt.Key_U, self.underlineID )
+ self.options.setAccel( TQt.CTRL+TQt.Key_U, self.underlineID )
self.options.connectItem( self.underlineID, self.underline )
self.isBold = FALSE
self.isUnderline = FALSE
self.options.setCheckable( TRUE )
- self.options = QPopupMenu()
+ self.options = TQPopupMenu()
#CHECK_PTR( self.options )
self.options.insertItem( "&Normal Font", self.normal )
self.options.insertSeparator()
@@ -204,28 +204,28 @@ class MenuExample( QWidget ):
self.isUnderline = FALSE
self.options.setCheckable( TRUE )
- self.help = QPopupMenu( self )
+ self.help = TQPopupMenu( self )
#CHECK_PTR( self.help )
- self.help.insertItem( "&About", self.about, Qt.CTRL+Qt.Key_H )
- self.help.insertItem( "About &Qt", self.aboutQt )
+ self.help.insertItem( "&About", self.about, TQt.CTRL+TQt.Key_H )
+ self.help.insertItem( "About &TQt", self.aboutTQt )
- self.menu = QMenuBar( self )
+ self.menu = TQMenuBar( self )
#CHECK_PTR( self.menu );
self.menu.insertItem( "&File", self.file )
self.menu.insertItem( "&Edit", self.edit )
self.menu.insertItem( "&Options", self.options )
self.menu.insertSeparator()
self.menu.insertItem( "&Help", self.help )
- self.menu.setSeparator( QMenuBar.InWindowsStyle )
+ self.menu.setSeparator( TQMenuBar.InWindowsStyle )
- self.label = QLabel( self )
+ self.label = TQLabel( self )
#CHECK_PTR( self.label )
self.label.setGeometry( 20, self.rect().center().y()-20, self.width()-40, 40 )
- self.label.setFrameStyle( QFrame.Box | QFrame.Raised )
+ self.label.setFrameStyle( TQFrame.Box | TQFrame.Raised )
self.label.setLineWidth( 1 )
- self.label.setAlignment( Qt.AlignCenter )
+ self.label.setAlignment( TQt.AlignCenter )
- self.label.setFont( QFont( "times", 12, QFont.Bold ) )
+ self.label.setFont( TQFont( "times", 12, TQFont.Bold ) )
self.connect( self, PYSIGNAL( "explain" ), self.label.setText )
#self.connect( self, PYSIGNAL( "explain(const char *)" ),
# self.label, SLOT( "setText(const char *)" ) )
@@ -268,13 +268,13 @@ class MenuExample( QWidget ):
self.emit(PYSIGNAL("explain"), ("Options/Underline selected",))
def about( self ):
- QMessageBox.about( self, "Qt Menu Example",
- "This example demonstrates simple use of Qt menus.\n"
+ TQMessageBox.about( self, "TQt Menu Example",
+ "This example demonstrates simple use of TQt menus.\n"
"You can cut and paste lines from it to your own\n"
"programs." )
- def aboutQt( self ):
- QMessageBox.aboutQt( self, "Qt Menu Example" )
+ def aboutTQt( self ):
+ TQMessageBox.aboutTQt( self, "TQt Menu Example" )
def printDoc( self ):
self.emit ( PYSIGNAL( "explain" ), ( "File/Printer/Print selected", ) )
@@ -291,7 +291,7 @@ class MenuExample( QWidget ):
def resizeEvent( self, ev ):
self.label.setGeometry( 20, self.rect().center().y()-20, self.width()-40, 40 )
-a = QApplication( sys.argv )
+a = TQApplication( sys.argv )
m = MenuExample()
a.setMainWidget( m )
@@ -5,7 +5,7 @@
#** Copyright (C) 1992-1998 Troll Tech AS. All rights reserved.
#**
-#** This file is part of an example program for PyQt. This example
+#** This file is part of an example program for PyTQt. This example
#** program may be used, distributed and modified without limitation.
#**
@@ -114,35 +114,35 @@ p4_xpm = [
# def sizeHint( self ):
-# return QFontMetrics( font ).size( Qt.AlignLeft | Qt.AlignVCenter | Qt.ShowPrefix | Qt.DontClip, string )
+# return TQFontMetrics( font ).size( TQt.AlignLeft | TQt.AlignVCenter | TQt.ShowPrefix | TQt.DontClip, string )
#
### Implementation of MenuExample class